# Section58Properties

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**section_58_centre_point** | [**GeoJSONCentrePoint**](GeoJSONCentrePoint.md) |  | 
**section_58_reference_number** | **str** |  | 
**section_58_status** | [**Section58StatusResponse**](Section58StatusResponse.md) |  | 
**section_58_status_string** | **str** |  | 
**street_name** | **str** |  | 
**area_name** | **str** |  | [optional] 
**organisation_name** | **str** |  | 
**start_date** | **datetime** |  | 
**end_date** | **datetime** |  | 
**restriction_duration** | [**Section58DurationResponse**](Section58DurationResponse.md) |  | 
**restriction_duration_string** | **str** |  | 
**restriction_extent** | [**Section58ExtentResponse**](Section58ExtentResponse.md) |  | 
**restriction_extent_string** | **str** |  | 
**location_types** | [**list[LocationTypeResponse]**](LocationTypeResponse.md) |  | 
**location_types_string** | **list[str]** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

